class Messages:
    SUCCESFUL_RESPONSE = "Succesful"
    CREATED_SUCCESFUL_RESPONSE = "Created"
    UPDATED_SUCCESFUL_RESPONSE = "Updated"
    DELETED_SUCCESFUL_RESPONSE = "Deleted"
    PARAM_REQUIRED = "You need to send all the required parameters"
    DATE_PARAM_REQUITED = "Don't forget to choose a Date"
    COULD_NOT_FIND = "Could not find any "
    MAIL_SENT = "Mail Message have been sent."
    COULD_NOT_CREATE="Could not create "
    RECORD_CANT_BE_DELETED = "This Record is being used, can't be deleted, \n please delete all the records where is being use first"
    TRUE_ARRAY_VALIDATOR = [True, "true", "True"]
    FALSE_ARRAY_VALIDATOR = [False, "false", "False"]



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="UtilsOptima", # Replace with your own username
    version="1.1.1",
    author="Cesar Corbacho",
    author_email="cesar.corbacho@tecnoglass.com",
    description="Usado para los metodos y mensajes comunmente usados en nuestros proyectos.",
    url="https://github.com/tecnoglass-optima/utils_optima",
    download_url = 'https://github.com/tecnoglass-optima/utils_optima/tarball/1.0',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)